package com.fs.his.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.his.domain.FsDfAccount;

/**
 * 代服账户Service接口
 *
 * @author fs
 * @date 2025-10-13
 */
public interface IFsDfAccountService extends IService<FsDfAccount>{
    /**
     * 查询代服账户
     *
     * @param id 代服账户主键
     * @return 代服账户
     */
    FsDfAccount selectFsDfAccountById(Long id);

    /**
     * 查询代服账户列表
     *
     * @param fsDfAccount 代服账户
     * @return 代服账户集合
     */
    List<FsDfAccount> selectFsDfAccountList(FsDfAccount fsDfAccount);

    /**
     * 新增代服账户
     *
     * @param fsDfAccount 代服账户
     * @return 结果
     */
    int insertFsDfAccount(FsDfAccount fsDfAccount);

    /**
     * 修改代服账户
     *
     * @param fsDfAccount 代服账户
     * @return 结果
     */
    int updateFsDfAccount(FsDfAccount fsDfAccount);

    /**
     * 批量删除代服账户
     *
     * @param ids 需要删除的代服账户主键集合
     * @return 结果
     */
    int deleteFsDfAccountByIds(Long[] ids);

    /**
     * 删除代服账户信息
     *
     * @param id 代服账户主键
     * @return 结果
     */
    int deleteFsDfAccountById(Long id);

    FsDfAccount selectFsDfAccountByAccount(String loginAccount);
}
